@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program. If not, see <http://www.gnu.org/licenses/>.
 """
 
-from flask import Flask, render_template, request, abort
+from flask import Flask, render_template, request, abort, Response
 from Blask.blasksettings import BlaskSettings
 from Blask.blogrenderer import BlogRenderer
 from Blask.errors import PageNotExistError
@@ -47,21 +47,16 @@ class BlaskApp:
             template_folder=self.settings["templateDir"],
             static_folder=self.settings["staticDir"],
         )
+        self.app.add_url_rule("/", endpoint="index", view_func=self._index, methods=["GET"])
+        self.app.add_url_rule("/sitemap.xml", view_func=self._get_sitemap, methods=["GET"])
+        self.app.add_url_rule("/<filename>", view_func=self._getpage, methods=["GET"])
         self.app.add_url_rule(
-            "/", endpoint="index", view_func=self._index, methods=["GET"])
-        self.app.add_url_rule(
-            "/<filename>", view_func=self._getpage, methods=["GET"])
-        self.app.add_url_rule(
-             "/<path:subpath>/<filename>", view_func=self._get_subpage, methods=["GET"])
-        self.app.add_url_rule(
-            "/tag/<tag>", view_func=self._gettag, methods=["GET"])
-        self.app.add_url_rule(
-            "/search", view_func=self.searchpages, methods=["POST"])
-        self.app.add_url_rule(
-            "/category/<category>", view_func=self._getcategory,
-            methods=["GET"])
-        self.app.add_url_rule(
-            "/author/<author>", view_func=self._getauthor, methods=["GET"])
+            "/<path:subpath>/<filename>", view_func=self._get_subpage, methods=["GET"]
+        )
+        self.app.add_url_rule("/tag/<tag>", view_func=self._gettag, methods=["GET"])
+        self.app.add_url_rule("/search", view_func=self.searchpages, methods=["POST"])
+        self.app.add_url_rule("/category/<category>", view_func=self._getcategory, methods=["GET"])
+        self.app.add_url_rule("/author/<author>", view_func=self._getauthor, methods=["GET"])
         # Register the error handler for each setting
         for error in self.settings["errors"].keys():
             self.app.register_error_handler(error, f=self._handle_http_errors)
@@ -75,8 +70,7 @@ class BlaskApp:
         template = entry.template
         if template is None:
             template = self.settings["defaultLayout"]
-        return render_template(
-            template, title=self.settings["title"], content=entry.content)
+        return render_template(template, title=self.settings["title"], content=entry.content)
 
     def _getpage(self, filename):
         """
@@ -100,7 +94,7 @@ class BlaskApp:
             title = self.settings["title"]
         else:
             title = entry.title
-        
+
         return render_template(
             template,
             title=title,
@@ -112,9 +106,19 @@ class BlaskApp:
         )
 
     def _get_subpage(self, subpath, filename):
-        subfilename = join(subpath,filename)
+        subfilename = join(subpath, filename)
         return self._getpage(subfilename)
 
+    def _get_sitemap(self):
+        """
+        render the sitemap.xml file
+        :returns: prints the sitemapfile
+        """
+        return Response(
+            self.blogrenderer.generate_sitemap_xml(self.settings["postDir"], request.url_root),
+            content_type="text/xml",
+        )
+
     def _gettag(self, tag):
         """
         Render the Tags Page.
@@ -124,9 +128,7 @@ class BlaskApp:
         postlist = self.blogrenderer.list_posts([tag])
         content = self.blogrenderer.generatetagpage(postlist)
         return render_template(
-            self.settings["defaultLayout"],
-            title=self.settings["title"],
-            content=content
+            self.settings["defaultLayout"], title=self.settings["title"], content=content
         )
 
     def searchpages(self):
@@ -137,9 +139,7 @@ class BlaskApp:
         postlist = self.blogrenderer.list_posts(search=request.form["search"])
         content = self.blogrenderer.generatetagpage(postlist)
         return render_template(
-            self.settings["defaultLayout"],
-            title=self.settings["title"],
-            content=content
+            self.settings["defaultLayout"], title=self.settings["title"], content=content
         )
 
     def _getcategory(self, category):
@@ -151,9 +151,7 @@ class BlaskApp:
         postlist = self.blogrenderer.list_posts(category=category)
         content = self.blogrenderer.generatetagpage(postlist)
         return render_template(
-            self.settings["defaultLayout"],
-            title=self.settings["title"],
-            content=content
+            self.settings["defaultLayout"], title=self.settings["title"], content=content
         )
 
     def _getauthor(self, author):
@@ -165,9 +163,7 @@ class BlaskApp:
         postlist = self.blogrenderer.list_posts(author=author)
         content = self.blogrenderer.generatetagpage(postlist)
         return render_template(
-            self.settings["defaultLayout"],
-            title=self.settings["title"],
-            content=content
+            self.settings["defaultLayout"], title=self.settings["title"], content=content
         )
 
     def _handle_http_errors(self, error_message):
@@ -176,7 +172,7 @@ class BlaskApp:
         :param errorMessage: Message error.
         :return: rendered custom error page.
         """
-        page = self.settings['errors'][error_message.code]
+        page = self.settings["errors"][error_message.code]
         return self._getpage(page)
 
     def run(self, **kwargs):
